==> haskell-kan-extensions-5.2.6-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-kan-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kan-extensions
version:              5.2.6
visibility:           public
id:                   kan-extensions-5.2.6-2DC6czDLwl01MBOpMMKbfv
key:                  kan-extensions-5.2.6-2DC6czDLwl01MBOpMMKbfv
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/kan-extensions/
synopsis:
    Kan extensions, Kan lifts, the Yoneda lemma, and (co)density (co)monads

description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads.

category:             Data Structures, Monads, Comonads, Functors
abi:                  cb6b828eaba34ab2647fbd125afd370c
exposed:              True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Coyoneda Data.Functor.Contravariant.Day
    Data.Functor.Contravariant.Yoneda Data.Functor.Coyoneda
    Data.Functor.Day Data.Functor.Day.Curried
    Data.Functor.Invariant.Day Data.Functor.Kan.Lan
    Data.Functor.Kan.Ran Data.Functor.Yoneda

import-dirs:          /usr/lib/ghc-9.4.8/site-local/kan-extensions-5.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/kan-extensions-5.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/kan-extensions-5.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-kan-extensions
hs-libraries:         HSkan-extensions-5.2.6-2DC6czDLwl01MBOpMMKbfv
depends:
    adjunctions-4.4.2-ForbUBtptLgFxuqD5qt97S array-0.5.4.0
    base-4.17.2.1 comonad-5.0.8-9doKR95co85HQUesdrJkPD containers-0.6.7
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    distributive-0.6.2.1-D3SXffd2XIlAT2MovnSdW4
    free-5.2-HhWVdOgT53PDesI8jmlVQC
    invariant-0.6.3-H7Ik41c2AlM1TkK6k4UxpN mtl-2.2.2
    profunctors-5.6.2-1y5eXinqMYuK1INvDQniNm
    semigroupoids-6.0.0.1-7jmB6QISbXh15MEXUZPyZv
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock

haddock-html:         /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-kan-extensions-5.2.6-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-kan-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kan-extensions
version:              5.2.6
visibility:           public
id:                   kan-extensions-5.2.6-KBwUD7iE9mqDwBNzY0H3ht
key:                  kan-extensions-5.2.6-KBwUD7iE9mqDwBNzY0H3ht
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/kan-extensions/
synopsis:
    Kan extensions, Kan lifts, the Yoneda lemma, and (co)density (co)monads

description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads.

category:             Data Structures, Monads, Comonads, Functors
abi:                  b19bd88eb10f649988db012c96c53365
exposed:              True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Coyoneda Data.Functor.Contravariant.Day
    Data.Functor.Contravariant.Yoneda Data.Functor.Coyoneda
    Data.Functor.Day Data.Functor.Day.Curried
    Data.Functor.Invariant.Day Data.Functor.Kan.Lan
    Data.Functor.Kan.Ran Data.Functor.Yoneda

import-dirs:          /usr/lib/ghc-9.4.8/site-local/kan-extensions-5.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/kan-extensions-5.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/kan-extensions-5.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-kan-extensions
hs-libraries:         HSkan-extensions-5.2.6-KBwUD7iE9mqDwBNzY0H3ht
depends:
    adjunctions-4.4.2-GpJ5NOQmhV2Gc73KfGUKSU array-0.5.4.0
    base-4.17.2.1 comonad-5.0.8-HjXm8wDvlWV5Uokq8mIEQc containers-0.6.7
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    distributive-0.6.2.1-LfGcGzJvOve9NvOUz2mt9r
    free-5.2-6XzfBaBNYAXDXFzJJLivZy
    invariant-0.6.3-DfrsRzAloe5B2t8pCobR8g mtl-2.2.2
    profunctors-5.6.2-FCezC193SLE8IKnRHeV6TK
    semigroupoids-6.0.0.1-EsDekxjOCgO6Hkl2ZFNy0d
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock

haddock-html:         /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
